@@ -1,10 +1,9 @@
 use std::fs;
-use std::path::Path;
 use crate::html_compiler;
 use crate::template_initializer;
 
 pub fn call() {
-    let page_path = page_folder_path();
+    let page_path = "templates/pages/";
     let pages = fs::read_dir(&page_path).unwrap();
 
     for page in pages {
@@ -14,11 +13,3 @@ pub fn call() {
         html_compiler::call(page_content, &output_filename);
     }
 }
-
-fn page_folder_path() -> String {
-    if Path::new("templates/pages").is_dir() {
-        "templates/pages/".to_string()
-    } else {
-        "default_templates/pages/".to_string()
-    }
-}
